@@ -17,7 +17,7 @@ except ImportError:
 
 from .utils.env import add_index_dir, get_document_rootdir
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 logging.basicConfig(level=logging.INFO, format="%(levelname)s: %(message)s")
 
@@ -57,8 +57,9 @@ class LittleHTTPRequestHandler(SimpleHTTPRequestHandler):
             actual_path = os.path.join(actual_path, word)
         return actual_path
 
-def parse_argument():
-    parser = argparse.ArgumentParser()
+def parse_argument(parents=None):
+    parent_parsers = parents if parents else []
+    parser = argparse.ArgumentParser(parents=parent_parsers)
     parser.set_defaults(doc_dirs=[], port=8000, index_dir=None,
             protocol="HTTP/1.0", server_type="process", verbose=False)
     parser.add_argument("-d", "--dir", dest="doc_dirs", action="append",
